VERSION 5.00
Begin {C62A69F0-16DC-11CE-9E98-00AA00574A4F} FormSelectNotes 
   Caption         =   "CommonNotes: BUILDER"
   ClientHeight    =   7590
   ClientLeft      =   45
   ClientTop       =   330
   ClientWidth     =   11550
   OleObjectBlob   =   "FormSelectNotes.frx":0000
   ShowModal       =   0   'False
   StartUpPosition =   1  'CenterOwner
End
Attribute VB_Name = "FormSelectNotes"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
' --------------------------------------------------------------------03/08/2007
' CommonNotes.swp                   Written by Leonard Kikstra,
'                                   Copyright 2003-2007, Leonard Kikstra
'                                   Downloaded from Lenny's SolidWorks Resources
'                                        at http://www.lennyworks.com/solidworks
' ------------------------------------------------------------------------------
' FormSelectNotes:  This is the main core of the macro where users can build
'                   notes, from predefined lists, that will be added to the
'                   drawing.  All other forms are accessed from here.
' ------------------------------------------------------------------------------
' Notes:            Source file must be in same directory as macro file.
'                   Source file must have macro name with '.ini' extension.
' ------------------------------------------------------------------------------
' Allow user to multi-select notes to add to drawing.
' Permits users to add/edit/remove notes in note builder.
' When user clicks "Apply", add all notes to drawing.
' Close and end program.
' -----------------------------------------------------------------------------
' Version   2.00  * Initial release
'           2.10  * Added 'Number notes from the bottom up' option in form and
'                 * Added option presets to CommonNotes.ini file
'           2.20  * Added code for handling notes without numbers.
'                 * Added note number toggle button.
'                 * Enhanced option settings and controls from ini file.
'           2.25  * Enhanced handling notes without numbers.
'                 * Change ListBoxBuild to multi-select for selecting numbering
'                   that also includes a preview of numbering scheme.
'                 * No longer handles notes with prefixed "~" symbol.
' 02/08/05  2.30  * Added code for custom bullet divider and note padding.
' 06/16/05  2.40  * Features added to allow user to add custom note(s), and to
'                   edit any note already in the note builder.
'                 * Corrected problem with manually sorting notes.  Problem
'                   occurred when note numbering fdeature added.  Need to fix
'                   note movement (column) in note builder.
' 09/01/06  2.50  * Added note Import/Export capabilities.
'                 * Added notepad style exiting capabilities.
' 03/08/07  2.55  * Added Lenny's SolidWorks Resources banner.
' -----------------------------------------------------------------------------
Dim Source As String
Dim AllowCustomTitle    As Boolean
Dim NoteNumberChange    As Boolean
Dim BuildBoxHeight      As Double
Const swDetailingNoteTextFormat = 0         ' Consistent with swconst.bas
Dim PaddedSpaces        As String
Dim NoteDividerSym      As String

Private Sub CommandEditNote_Click()                                  ' v2.40
  CustomNote = ListBoxBuild.List(ListBoxBuild.ListIndex, 1)          ' routine
  FormCustomNote.Show
  If CustomNote <> "" Then
    ListBoxBuild.List(ListBoxBuild.ListIndex, 1) = CustomNote
  End If
End Sub

Private Sub CommandAddNote_Click()                                   ' v2.40
  CustomNote = ""                                                    ' routine
  FormCustomNote.Show
  If CustomNote <> "" Then
    ListBoxBuild.AddItem ""
    ListBoxBuild.List(ListBoxBuild.ListCount - 1, 1) = CustomNote
  End If
End Sub

Private Sub CommandExport_Click()                                     ' v2.50
  NoteFileName = "" & "_NOTES.txt"                                    ' routine
End Sub

Private Sub CommandNotePad_Click()                                    ' v2.50
  FormNotePad.TextBoxEditor = ""                                      ' routine
  For x = 0 To ListBoxBuild.ListCount - 1
    FormNotePad.TextBoxEditor = FormNotePad.TextBoxEditor & _
                ListBoxBuild.List(x, 1) & Chr(10)
  Next x
  FormNotePad.Show
End Sub

Private Sub ListBoxBuild_DblClick(ByVal Cancel As MSForms.ReturnBoolean)
  If (ListBoxBuild.ListCount > 0) And (ListBoxBuild.ListIndex > -1) Then
    CustomNote = ListBoxBuild.List(ListBoxBuild.ListIndex, 1)         ' routine
    FormCustomNote.Show
    If CustomNote <> "" Then
      ListBoxBuild.List(ListBoxBuild.ListIndex, 1) = CustomNote
    End If
  End If
End Sub

Private Sub ListBoxType_Change()
  ListBoxNOTES.Clear
  Open Source For Input As #1               ' Open file for input.
  ' Read group specific notes.
  Do While Not EOF(1)                       ' Loop until end of file.
    Input #1, Reader                        ' Read data into variable.
    If UCase(Reader) = "[" + (UCase(ListBoxType.List(ListBoxType.ListIndex))) + "]" _
                     Then                   ' Find specific group
      Do While Not EOF(1)                   ' Loop until end of file.
        Input #1, LineItem                  ' Read data into material variable.
        If LineItem <> "" Then
          ListBoxNOTES.AddItem LineItem     ' Add item to list
        Else
          GoTo EndReadNotes1
        End If
      Loop
    End If
  Loop
EndReadNotes1:
  Close #1    ' Close file.
End Sub

Private Sub ListBoxNOTES_Click()
  ListBoxBuild.AddItem ""
  ListBoxBuild.List(ListBoxBuild.ListCount - 1, 1) = _
                ListBoxNOTES.List(ListBoxNOTES.ListIndex)               ' v2.20
  ControlSetup                                                          ' v2.20
End Sub

Private Sub ListBoxBuild_Click()
  ControlSetup                                                          ' v2.20
  If ListBoxBuild.ListIndex >= 0 Then
    CommandRemove.enabled = True
    CommandEditNote.enabled = True
    NoteNumberControls
  End If
  If ListBoxBuild.ListIndex > 0 Then _
            CommandMoveUp.enabled = True
  If ListBoxBuild.ListIndex < ListBoxBuild.ListCount - 1 Then _
            CommandMoveDown.enabled = True
End Sub

Private Sub ListBoxBuild_Change()
  If ListBoxBuild.ListStyle = fmListStyleOption Then
    UpdateNumbers
  End If
End Sub

Private Sub CommandMoveUp_Click()                                       ' v2.40
  If ListBoxBuild.ListCount > 1 Then                                    ' fixed
    Temp = ListBoxBuild.List(ListBoxBuild.ListIndex, 1)                 ' routine
    ListBoxBuild.List(ListBoxBuild.ListIndex, 1) _
            = ListBoxBuild.List(ListBoxBuild.ListIndex - 1, 1)
    ListBoxBuild.List(ListBoxBuild.ListIndex - 1, 1) = Temp
    ListBoxBuild.ListIndex = ListBoxBuild.ListIndex - 1
  End If
End Sub

Private Sub CommandMoveDown_Click()                                     ' v2.40
  If ListBoxBuild.ListCount > 1 Then                                    ' fixed
    Temp = ListBoxBuild.List(ListBoxBuild.ListIndex, 1)                 ' routine
    ListBoxBuild.List(ListBoxBuild.ListIndex, 1) _
            = ListBoxBuild.List(ListBoxBuild.ListIndex + 1, 1)
    ListBoxBuild.List(ListBoxBuild.ListIndex + 1, 1) = Temp
    ListBoxBuild.ListIndex = ListBoxBuild.ListIndex + 1
  End If
End Sub

Private Sub CommandRemove_Click()
  'Ensure ListBox contains list items
  If ListBoxBuild.ListCount > 0 Then
    'If no selection, choose last list item.
    If ListBoxBuild.ListIndex = -1 Then
      ListBoxBuild.ListIndex = ListBoxBuild.ListCount - 1
    End If
    Position = ListBoxBuild.ListIndex
    ListBoxBuild.RemoveItem (ListBoxBuild.ListIndex)
    ListBoxBuild.ListIndex = -1
  End If
  ControlSetup                                                          ' v2.20
End Sub

Private Sub CommandClearAll_Click()
  ListBoxBuild.Clear
  ControlSetup                                                          ' v2.20
End Sub

Private Sub CommandNoteNumber_Click()
  ListBoxBuild.ListIndex = -1
  ' v2.20 routine added
  ' v2.25 routine re-written
  If ListBoxBuild.ListStyle = fmListStylePlain Then
    CommandMoveUp.enabled = False
    CommandMoveDown.enabled = False
    CommandRemove.enabled = False
    CommandEditNote.enabled = False
    CommandClearAll.enabled = False
    ListBoxBuild.ColumnWidths = "25 pt;280 pt"
    ListBoxBuild.MultiSelect = fmMultiSelectMulti
    ListBoxBuild.ListStyle = fmListStyleOption
    For x = 0 To ListBoxBuild.ListCount - 1
      ListBoxBuild.Selected(x) = True
    Next x
    ListBoxType.enabled = False
    ListBoxType.ForeColor = vbGrayText
    ListBoxNOTES.enabled = False
    ListBoxNOTES.ForeColor = vbGrayText
    CommandNoteNumber.Caption = "Add More Notes"
    CommandAllNotes.enabled = True
    CommandNoNotes.enabled = True
    UpdateNumbers
  Else
    Answer = MsgBox("Note numbering will be lost." & Chr(13) & Chr(13) & "Continue?", vbYesNo + vbExclamation, "Warning:")
    If Answer = vbYes Then
      CommandMoveUp.enabled = True
      CommandMoveDown.enabled = True
      CommandRemove.enabled = True
      CommandEditNote.enabled = True
      CommandClearAll.enabled = True
      ListBoxBuild.ColumnWidths = "1 pt;310 pt"
      ListBoxBuild.MultiSelect = fmMultiSelectSingle
      ListBoxBuild.ListStyle = fmListStylePlain
      For x = 0 To ListBoxBuild.ListCount - 1
        ListBoxBuild.Selected(x) = False
      Next x
      ListBoxType.enabled = True
      ListBoxType.ForeColor = vbWindowText
      ListBoxNOTES.enabled = True
      ListBoxNOTES.ForeColor = vbWindowText
      CommandNoteNumber.Caption = "Edit Note Numbers"
      CommandAllNotes.enabled = False
      CommandNoNotes.enabled = False
    End If
  End If
End Sub

Private Sub CommandAllNotes_Click()
  For x = 0 To ListBoxBuild.ListCount - 1
    ListBoxBuild.Selected(x) = True
  Next x
End Sub

Private Sub CommandNoNotes_Click()
  For x = 0 To ListBoxBuild.ListCount - 1
    ListBoxBuild.Selected(x) = False
  Next x
End Sub

Private Sub CheckBoxNumberBottomUp_Click()
  UpdateNumbers
End Sub

Private Sub CheckBoxNoteNumberSkip_Click()
  UpdateNumbers
End Sub

Private Sub UpdateNumbers()
  Counter = 0
  For x = 0 To ListBoxBuild.ListCount - 1
    Counter = Counter + 1
    If CheckBoxNumberBottomUp.Value = False Then
      y = x
    Else
      y = (ListBoxBuild.ListCount - 1) - x
    End If
    If (ListBoxBuild.Selected(y) = True) Then
      ListBoxBuild.List(y, 0) = LTrim(Str(Counter)) _
                    & NoteDividerSym & " "                              ' v2.30
    Else
      ListBoxBuild.List(y, 0) = PaddedSpaces
      If CheckBoxNoteNumberSkip.Value = False Then
        Counter = Counter - 1
      End If
    End If
  Next x
End Sub

Private Sub NoteNumberControls()
  CommandNoteNumber.enabled = False
  CommandAllNotes.enabled = False
  CommandNoNotes.enabled = False
  CheckBoxNumberBottomUp.enabled = False
  CheckBoxNoteNumberSkip.enabled = False
  FrameNoteNumbering.enabled = False
  If (NoteNumberChange = True) _
            And (ListBoxBuild.ListCount > -1) Then
      CommandNoteNumber.enabled = True
      CommandAllNotes.enabled = True
      CommandNoNotes.enabled = True
      CheckBoxNumberBottomUp.enabled = True
      CheckBoxNoteNumberSkip.enabled = True
      FrameNoteNumbering.enabled = True
    Else
  End If
End Sub

Private Sub CommandAddNotes_Click()
  Set swSelMgr = Document.SelectionManager
  Set swSelData = swSelMgr.CreateSelectData
  If ListBoxBuild.ListCount >= 1 Then                                   ' v2.25
    ' If user hasn't used note selection, then select all notes.        '
    If ListBoxBuild.ListStyle = fmListStylePlain Then                   '
     ListBoxBuild.MultiSelect = fmMultiSelectMulti                      '
      ListBoxBuild.Height = 117.8                                       '
      ListBoxBuild.ListStyle = fmListStyleOption                        '
      For x = 0 To ListBoxBuild.ListCount - 1                           '
        ListBoxBuild.Selected(x) = True                                 '
      Next x                                                            '
      UpdateNumbers                                                     '
    End If                                                              '
    ' Begin creating note text                                          '
    For x = 0 To ListBoxBuild.ListCount - 1     ' Each line item in list
      If CheckBoxUpperCase.Value = True Then                            ' v2.25
        TextLine = ListBoxBuild.List(x, 0) + UCase(ListBoxBuild.List(x, 1))
      Else                                                              '
        TextLine = ListBoxBuild.List(x, 0) + ListBoxBuild.List(x, 1)    '
      End If                                                            '
      If TextBoxWidth.Value > 0 Then
        TempText = TextLine
        While CInt(Len(TempText)) > CInt(TextBoxWidth.Value)
          For z = 1 To TextBoxWidth.Value
            If Mid(TempText, z, 1) = " " Then
              LastSpace = z
            End If
          Next
          TempText2 = Left(TempText, LastSpace)
          Text = Text + TempText2 + Chr$(13) + Chr$(10) ' Add to text variable
          TempText = PaddedSpaces + Right(TempText, Len(TempText) - Len(TempText2))
        Wend
        Text = Text + TempText + Chr$(13) + Chr$(10)    ' Add to text variable
      Else
        Text = Text + TempText + Chr$(13) + Chr$(10)    ' Add to text variable
      End If
      If (CheckLineSpace.Value = True) _
      And (x <> ListBoxBuild.ListCount - 1) Then
        Text = Text + Chr$(13) + Chr$(10)       ' Add line space between notes
      End If
    Next x                                      ' Next line item
    If CheckHighlightTitle = True Then
      Set note = Document.InsertNote(UCase(ComboTitle.Text))
                                                  ' Create first annotaion
      If Not note Is Nothing Then                 ' Note is valid
        note.angle = 0                            ' Set note angle
        boolstatus = note.SetBalloon(0, 1)        ' Set balloon options
        Set Annotation = note.GetAnnotation()     ' Get annotation object
        If Not Annotation Is Nothing Then         ' Annotation is valid
          Set Anote = Annotation.GetSpecificAnnotation
          Set textFormat = _
              Document.GetUserPreferenceTextFormat(swDetailingNoteTextFormat)
                                                  ' Get document's text format
          textFormat.Underline = True                         ' Underline note
          textFormat.CharHeight = textFormat.CharHeight * 1.5 ' Set char height
          Anote.SetTextFormat False, textFormat               ' False = use my settings
          ' Set leader options and position note.
          longstatus = Annotation.SetLeader2(False, 0, True, True, False, False)
          boolstatus = Annotation.SetPosition(PickPt(0), PickPt(1), PickPt(2))
        End If
      End If
      Set note = Document.InsertNote(Text)        ' Create second annotaion
      If Not note Is Nothing Then                 ' Note is valid
        note.angle = 0                            ' Set note angle
        boolstatus = note.SetBalloon(0, 1)        ' Set balloon options
        Set Annotation = note.GetAnnotation()     ' Get annotation object
        If Not Annotation Is Nothing Then         ' Annotation is valid
          Set Anote = Annotation.GetSpecificAnnotation
          Set textFormat = _
              Document.GetUserPreferenceTextFormat(swDetailingNoteTextFormat)
                                                  ' Get document's text format
          Anote.SetTextFormat True, textFormat    ' True = use document settings
          ' Set leader options and position note.
          longstatus = Annotation.SetLeader2(False, 0, True, True, False, False)
          boolstatus = Annotation.SetPosition(PickPt(0), PickPt(1) - 0.01, PickPt(2))
        End If
      Document.ClearSelection2 True               ' Clear selection     ' v2.30
      retval = Annotation.Select3(False, swSelData)                     ' v2.30
      End If
    Else
      If CheckLineSpace = True Then               ' Create single annotaion
        Set note = Document.InsertNote(UCase(ComboTitle.List(ComboTitle.ListIndex, 0)) _
                   + Chr$(13) + Chr$(10) + Chr$(13) + Chr$(10) + Text)
      Else
        Set note = Document.InsertNote(UCase(ComboTitle.List(ComboTitle.ListIndex, 0)) _
                   + Chr$(13) + Chr$(10) + Text)
      End If
      If Not note Is Nothing Then                 ' Note is valid
        note.angle = 0                            ' Set note angle
        boolstatus = note.SetBalloon(0, 1)        ' Set balloon options
        Set Annotation = note.GetAnnotation()     ' Get annotation object
        If Not Annotation Is Nothing Then         ' Annotation is valid
          Set Anote = Annotation.GetSpecificAnnotation
          Set textFormat = _
              Document.GetUserPreferenceTextFormat(swDetailingNoteTextFormat)
                                                  ' Get document's text format
          Anote.SetTextFormat True, textFormat    ' True = use document settings
          ' Set leader options and position note.
          longstatus = Annotation.SetLeader2(False, 0, True, True, False, False)
          boolstatus = Annotation.SetPosition(PickPt(0), PickPt(1), PickPt(2))
        End If
      End If
    End If
    Document.ClearSelection2 True               ' Clear selection
    Document.WindowRedraw                       ' Redraw screen
  Else
    MsgBox "No user notes selected or added.", vbExclamation
  End If
  End
End Sub

Private Sub CommandCancel_Click()
  End
End Sub

Private Sub ControlSetup()                                              ' v2.20
  CommandMoveUp.enabled = False                                         ' routine
  CommandMoveDown.enabled = False                                       ' added
  CommandRemove.enabled = False
  CommandEditNote.enabled = False
  CommandClearAll.enabled = False
  If ListBoxBuild.ListCount > 0 Then
    CommandClearAll.enabled = True
  End If
  NoteNumberControls
End Sub

Private Sub ReadSource()
  Open Source For Input As #1               ' Open file for input.
  Do While Not EOF(1)                       ' Loop until end of file.
    Input #1, Reader                        ' Read data into variable.
    If Reader = "[GROUPS]" Then
      Do While Not EOF(1)                   ' Loop until end of file.
        Input #1, LineItem                  ' Read data into material variable.
        If LineItem <> "" Then
          ListBoxType.AddItem LineItem      ' Add item to list
        Else
          GoTo EndReadNotes
        End If
      Loop
EndReadNotes:
    ElseIf Reader = "[GLOBAL OPTIONS]" Then
      ' Read and set options that are 'Global' to the program
      Do While Not EOF(1)                 ' Loop until end of file.
        Input #1, OptionLine              ' Read data into variable.
        If OptionLine <> "" Then
          If UCase(Left$(OptionLine, 11)) = UCase("ColumnWidth") Then
            TextBoxWidth.Value = Mid$(OptionLine, 13)
          
          ElseIf UCase(Left$(OptionLine, 12)) = UCase("PaddedSpaces") Then
            PaddedSpaces = ""                                           ' v2.25
            For x = 1 To Mid$(OptionLine, 14)                           '
              PaddedSpaces = PaddedSpaces & " "                         '
            Next x                                                      ' v2.25
          
          ElseIf UCase(Left$(OptionLine, 14)) = UCase("NoteDividerSym") Then
            NoteDividerSym = Mid$(OptionLine, 16)                       ' v2.30

          ElseIf UCase(Left$(OptionLine, 14)) = UCase("HighlightTitle") Then
            If UCase(Mid$(OptionLine, 16)) = "TRUE" Then
              CheckHighlightTitle.Value = True
            ElseIf UCase(Mid$(OptionLine, 16)) = "FALSE" Then           ' v2.20
              CheckHighlightTitle.Value = False                         ' v2.20
            End If
          ElseIf UCase(Left$(OptionLine, 21)) = UCase("DisableHighlightTitle") _
            Then                                                        ' v2.20
            If UCase(Mid$(OptionLine, 23)) = "TRUE" Then                '
              CheckHighlightTitle.enabled = False                       '
            ElseIf UCase(Mid$(OptionLine, 23)) = "FALSE" Then           '
              CheckHighlightTitle.enabled = True                        ' v2.20
            End If
          ElseIf UCase(Left$(OptionLine, 16)) = UCase("AllowCustomTitle") Then
            If UCase(Mid$(OptionLine, 18)) = "TRUE" Then
              AllowCustomTitle = True
            ElseIf UCase(Mid$(OptionLine, 18)) = "FALSE" Then           ' v2.20
              AllowCustomTitle = False                                  ' v2.20
            End If
          
          ElseIf UCase(Left$(OptionLine, 11)) = UCase("LineSpacing") Then
            If UCase(Mid$(OptionLine, 13)) = "TRUE" Then
              CheckLineSpace.Value = True
            ElseIf UCase(Mid$(OptionLine, 13)) = "FALSE" Then           ' v2.20
              CheckLineSpace.Value = False                              ' v2.20
            End If
          ElseIf UCase(Left$(OptionLine, 18)) = UCase("DisableLineSpacing") Then
            If UCase(Mid$(OptionLine, 20)) = "TRUE" Then                ' v2.20
              CheckLineSpace.enabled = False                            '
            ElseIf UCase(Mid$(OptionLine, 20)) = "FALSE" Then           '
              CheckLineSpace.enabled = True                             '
            End If                                                      ' v2.20
          
          ElseIf UCase(Left$(OptionLine, 14)) = UCase("BottomUpOption") Then
            If UCase(Mid$(OptionLine, 16)) = "TRUE" Then
              CheckBoxNumberBottomUp.Value = True
            ElseIf UCase(Mid$(OptionLine, 16)) = "FALSE" Then           ' v2.20
              CheckBoxNumberBottomUp.Value = False                      ' v2.20
            End If
          ElseIf UCase(Left$(OptionLine, 21)) = UCase("DisableBottomUpOption") Then
            If UCase(Mid$(OptionLine, 23)) = "TRUE" Then                ' v2.20
              CheckBoxNumberBottomUp.enabled = False                    '
            ElseIf UCase(Mid$(OptionLine, 23)) = "FALSE" Then           '
              CheckBoxNumberBottomUp.enabled = True                     '
            End If                                                      ' v2.20
          
          ElseIf UCase(Left$(OptionLine, 14)) = UCase("NoteNumberSkip") Then
            If UCase(Mid$(OptionLine, 16)) = "TRUE" Then                ' v2.20
              CheckBoxNoteNumberSkip.Value = True                       '
            ElseIf UCase(Mid$(OptionLine, 16)) = "FALSE" Then           '
              CheckBoxNoteNumberSkip.Value = False                      '
            End If                                                      ' v2.20
          ElseIf UCase(Left$(OptionLine, 21)) = UCase("DisableNoteNumberSkip") _
            Then                                                        ' v2.20
            If UCase(Mid$(OptionLine, 23)) = "TRUE" Then                '
              CheckBoxNoteNumberSkip.enabled = False                    '
            ElseIf UCase(Mid$(OptionLine, 23)) = "FALSE" Then           '
              CheckBoxNoteNumberSkip.enabled = True                     '
            End If                                                      ' v2.20
          ElseIf UCase(Left$(OptionLine, 23)) = UCase("DisableNoteNumberChange") _
            Then                                                        ' v2.20
            If UCase(Mid$(OptionLine, 25)) = "TRUE" Then                '
              NoteNumberChange = False                                  '
            Else                                                        '
              NoteNumberChange = True                                   '
            End If                                                      ' v2.20
            NoteNumberControls                                          '
          
          ElseIf UCase(Left$(OptionLine, 19)) = UCase("ForceUpperCaseNotes") Then
            If UCase(Mid$(OptionLine, 21)) = "TRUE" Then                ' v2.20
              CheckBoxUpperCase.Value = True                            '
            Else                                                        '
              CheckBoxUpperCase.Value = False                           '
            End If                                                      ' v2.20
          ElseIf UCase(Left$(OptionLine, 26)) = UCase("DisableForceUpperCaseNotes") _
            Then                                                        ' v2.20
            If UCase(Mid$(OptionLine, 28)) = "TRUE" Then                '
              CheckBoxUpperCase.enabled = False                         '
            ElseIf UCase(Mid$(OptionLine, 28)) = "FALSE" Then           '
              CheckBoxUpperCase.enabled = True                          '
            End If                                                      ' v2.20
          
          End If
        Else
          GoTo EndReadOptions
        End If
      Loop
EndReadOptions:
    ElseIf Reader = "[TITLES]" Then
      ' Read and set options that are 'Global' to the program
      ComboTitle.Clear
      Do While Not EOF(1)                 ' Loop until end of file.
        Input #1, TitleLine               ' Read data into variable.
        If TitleLine <> "" Then
          ComboTitle.AddItem TitleLine
          ComboTitle.enabled = True
          ComboTitle.BackColor = vbWindowBackground
        Else
          GoTo EndReadTitles
        End If
      Loop
EndReadTitles:
      ComboTitle.ListIndex = 0
    End If
  Loop
  Close #1    ' Close file.
End Sub

Private Sub SetDefaults()
  MsgBox "Source file not found. Using defaults.", vbExclamation
  ComboTitle.Locked = True
  ListBoxType.Locked = True
  CheckHighlightTitle.Value = True
  AllowCustomTitle = True
  CheckLineSpace.Value = True
  CheckBoxNumberBottomUp.Value = False                                  ' v2.25
  CheckBoxNoteNumberSkip.Value = False                                  '
  NoteNumberChange = True                                               '
  CheckBoxNoteNumberSkip.enabled = True                                 '
  NoteNumberChange = True                                               '
  CheckBoxUpperCase.Value = True                                        '
  CheckBoxUpperCase.enabled = True                                      '
  ListBoxNOTES.AddItem "Symmetrical about centerline except as noted."
  ListBoxNOTES.AddItem "Dimensions are to theoretical sharp corners."
  ListBoxNOTES.AddItem "Unless otherwise noted, all radii to be R.xx."
  ListBoxNOTES.AddItem "Break all sharp edges."
  ListBoxNOTES.AddItem "Remove weld spatter and debris."
  ListBoxNOTES.AddItem "Component must rotate freely after assembly."
End Sub

Private Sub LSRBanner_Click()
  FormAbout.Show
End Sub

Private Sub CommandAbout_Click()
  FormAbout.Show
End Sub
Private Sub UserForm_Initialize()
  ' Show program version
  ProgramVersion.Caption = "Version: v" & version
  PaddedSpaces = "    "
  ComboTitle.AddItem "NOTES:"
  ComboTitle.ListIndex = 0
  ComboTitle.enabled = False
  ComboTitle.BackColor = vbButtonFace
  CheckHighlightTitle = False
  CheckLineSpace = False
  AllowCustomTitle = False
  ' Clear group list box and read group names from external file
  ListBoxType.Clear
  ' Read group names and setup group list box.
  Source = swApp.GetCurrentMacroPathName             ' Get macro path+filename
  Source = Left$(Source, Len(Source) - 3) + "ini"    ' Set source filename
  Set FileSys = CreateObject("Scripting.FileSystemObject")
  If FileSys.FileExists(Source) Then                 ' Does source file exist?
    ReadSource                                       ' Yes, read file
    ListBoxType.ListIndex = 0
  Else
    SetDefaults                                      ' No, use macro defaults
  End If
  If AllowCustomTitle = True Then
    ComboTitle.Style = fmStyleDropDownCombo
  Else
    ComboTitle.Style = fmStyleDropDownList
    If ComboTitle.ListCount = 1 Then
      ComboTitle.enabled = False
      ComboTitle.BackColor = vbButtonFace
    End If
  End If
  ControlSetup                                                          ' v2.20
  ListBoxBuild.Clear
  BuildBoxHeight = ListBoxBuild.Height
  CommandAllNotes.enabled = False
  CommandNoNotes.enabled = False
End Sub

